@@ -16,8 +16,8 @@ fast.incremental.association.optimized = function(x, whitelist, blacklist,
 
   }#FOR
 
-  # check markov blankets' consistency.
-  mb = mb.recovery(mb, nodes = nodes, strict = strict, debug = debug)
+  # check markov blankets for consistency.
+  mb = bn.recovery(mb, nodes = nodes, strict = strict, mb = TRUE, debug = debug)
 
   # 2. [Compute Graph Structure]
   for (node in nodes) {
@@ -34,8 +34,8 @@ fast.incremental.association.optimized = function(x, whitelist, blacklist,
   # update mb with the results of neighbour().
   mb = mb2
 
-  # hope it's never called ...
-  mb = nbr.recovery(mb, nodes = nodes, strict = strict, debug = debug)
+  # check neighbourhood sets for consistency.
+  mb = bn.recovery(mb, nodes = nodes, strict = strict, debug = debug)
 
   return(mb)
 
@@ -52,8 +52,8 @@ fast.incremental.association.cluster = function(x, cluster, whitelist,
          blacklist = blacklist, test = test, debug = debug)
   names(mb) = nodes
 
-  # check markov blankets' consistency.
-  mb = mb.recovery(mb, nodes = nodes, strict = strict, debug = debug)
+  # check markov blankets for consistency.
+  mb = bn.recovery(mb, nodes = nodes, strict = strict, mb = TRUE, debug = debug)
 
   # 2. [Compute Graph Structure]
   mb = parLapply(cluster, as.list(nodes), neighbour, mb = mb, data = x,
@@ -61,8 +61,8 @@ fast.incremental.association.cluster = function(x, cluster, whitelist,
          test = test, debug = debug)
   names(mb) = nodes
 
-  # hope it's never called ...
-  mb = nbr.recovery(mb, nodes = nodes, strict = strict, debug = debug)
+  # check neighbourhood sets for consistency.
+  mb = bn.recovery(mb, nodes = nodes, strict = strict, debug = debug)
 
   return(mb)
 
@@ -79,8 +79,8 @@ fast.incremental.association = function(x, whitelist, blacklist, test,
          blacklist = blacklist, test = test, debug = debug)
   names(mb) = nodes
 
-  # check markov blankets' consistency.
-  mb = mb.recovery(mb, nodes = nodes, strict = strict, debug = debug)
+  # check markov blankets for consistency.
+  mb = bn.recovery(mb, nodes = nodes, strict = strict, mb = TRUE, debug = debug)
 
   # 2. [Compute Graph Structure]
   mb = lapply(as.list(nodes), neighbour, mb = mb, data = x, alpha = alpha,
@@ -88,8 +88,8 @@ fast.incremental.association = function(x, whitelist, blacklist, test,
          debug = debug)
   names(mb) = nodes
 
-  # hope it's never called ...
-  mb = nbr.recovery(mb, nodes = nodes, strict = strict, debug = debug)
+  # check neighbourhood sets for consistency.
+  mb = bn.recovery(mb, nodes = nodes, strict = strict, debug = debug)
 
   return(mb)
 
