@@ -1,14 +1,10 @@
 
-#include <R.h>
-#include <Rinternals.h>
-
-#define INT(x) INTEGER(x)[0]
-#define NUM(x) REAL(x)[0]
+#include "common.h"
 
 SEXP dlik (SEXP x, SEXP lx, SEXP length) {
 
   int i = 0, k = 0;
-  unsigned int *n;
+  int *n;
   SEXP result;
 
   PROTECT(result = allocVector(REALSXP, 1));
@@ -17,8 +13,7 @@ SEXP dlik (SEXP x, SEXP lx, SEXP length) {
   NUM(result) = 0;
 
   /* initialize the contingency table. */
-  n = (unsigned int *) R_alloc(INT(lx), sizeof(int));
-  memset(n, '\0', sizeof(int) * INT(lx));
+  n = alloc1dcont(INT(lx));
 
   /* compute the joint frequency of x and y. */
   for (k = 0; k < INT(length); k++) {
@@ -44,7 +39,7 @@ SEXP dlik (SEXP x, SEXP lx, SEXP length) {
 SEXP cdlik (SEXP x, SEXP y, SEXP lx, SEXP ly, SEXP length) {
 
   int i = 0, j = 0, k = 0;
-  unsigned int **n, *nj;
+  int **n, *nj;
   SEXP result;
 
   PROTECT(result = allocVector(REALSXP, 1));
@@ -52,18 +47,9 @@ SEXP cdlik (SEXP x, SEXP y, SEXP lx, SEXP ly, SEXP length) {
   /* initialize result to zero. */
   NUM(result) = 0;
 
-  /* initialize the contingency table. */
-  n = (unsigned int **) R_alloc(INT(lx), sizeof(int *));
-  for (i = 0; i < INT(lx); i++) {
-
-    n[i] = (unsigned int *) R_alloc(INT(ly), sizeof(int));
-    memset(n[i], '\0', sizeof(int) * INT(ly));
-
-  }/*FOR*/
-
-  /* initialize the marginal frequencies. */
-  nj = (unsigned int *) R_alloc(INT(ly), sizeof(int));
-  memset(nj, '\0', sizeof(int) * INT(ly));
+  /* initialize the contingency table and the marginal frequencies. */
+  n = alloc2dcont(INT(lx), INT(ly));
+  nj = alloc1dcont(INT(ly));
 
   /* compute the joint frequency of x and y. */
   for (k = 0; k < INT(length); k++) {
